#ifndef NT2_INCLUDE_CONSTANTS_SIX_HPP_INCLUDED
#define NT2_INCLUDE_CONSTANTS_SIX_HPP_INCLUDED

#include <nt2/constant/include/constants/six.hpp>

#endif
